@@ -1,7 +1,8 @@
-from .lambda_function import LambdaFunction
+from .function import LambdaFunction
 import simplejson as json
 import re
 import decimal
+from datetime import datetime
 
 
 # class DecimalEncoder(json.JSONEncoder):
@@ -34,6 +35,7 @@ class APIFunction(LambdaFunction):
             print("Returning options payload:")
             response = self.create_return()
             print(response)
+            print(event)
 
         else:
             raise Exception(f"Triggered with unexpected HTTP method {method}.")
@@ -50,7 +52,7 @@ class APIFunction(LambdaFunction):
         }
         return_obj["headers"] = headers
         if body:
-            return_obj["body"] = json.dumps(body)
+            return_obj["body"] = json.dumps(body, default=datetime.isoformat)
         return return_obj
 
     def get_methods(self):
